@@ -1,6 +1,6 @@
 #!/usr/local/bin/perl
 #
-# $Header: /u1/project/ARSperl/ARSperl/example/RCS/GetCharMenu.pl,v 1.3 1998/02/25 19:21:32 jcmurphy Exp $
+# $Header: /u1/project/ARSperl/ARSperl/example/RCS/GetCharMenu.pl,v 1.4 1998/09/16 14:38:31 jcmurphy Exp $
 #
 # NAME
 #   GetCharMenu.pl
@@ -16,6 +16,9 @@
 #   jcmurphy@acsu.buffalo.edu
 #
 # $Log: GetCharMenu.pl,v $
+# Revision 1.4  1998/09/16 14:38:31  jcmurphy
+# updated changeDiary code
+#
 # Revision 1.3  1998/02/25 19:21:32  jcmurphy
 # updated to printout query if query style menu
 #
@@ -65,6 +68,13 @@ print "timestamp   : ".localtime($finfo->{"timestamp"})."\n";
 print "owner       : ".$finfo->{"owner"}."\n";
 print "lastChanged : ".$finfo->{"lastChanged"}."\n";
 print "changeDiary : ".$finfo->{"changeDiary"}."\n";
+
+foreach (@{$finfo->{"changeDiary"}}) {
+    print "\tTIME: ".localtime($_->{"timestamp"})."\n";
+    print "\tUSER: $_->{"user"}\n";
+    print "\tWHAT: $_->{"value"}\n";
+}
+
 print "refreshCode : ".$finfo->{"refreshCode"}."\n";
 print "menuType    : ".
     ("None", "List", "Query", "File", "SQL")[$finfo->{"menuType"}]." ($finfo->{menuType})\n";
